pub fn emit(category: DiagCategory, level: DiagLevel, event: DiagEventKind)Expand description
Emit a diagnostic event if the given category and level pass the current filter.
This is the primary entry point for all diagnostic events. The event is automatically timestamped and tagged with the current frame number.